@@ -14,7 +14,7 @@ import warnings
 from numba.core.errors import NumbaWarning
 warnings.filterwarnings("ignore", category=NumbaWarning)
 
-__version__ = "0.7.7"
+__version__ = "0.7.8"
 
 
 class SAMGUI(object):
@@ -31,9 +31,32 @@ class SAMGUI(object):
 
         if sam is not None:
             self.log('Initializing GUI from input SAM object.')
+            if not isinstance(sam,list):
+                sams=[sam]
+            else:
+                sams = sam
+                sam = sams[0]           
             self.init_from_sam(sam)
             self.create_plot(0, "Full dataset")
             items = [self.stab, self.tab]
+            
+            for i in range(1,len(sams)):
+                self.sams.append(sams[i])
+                self.selected.append(np.ones(sams[i].adata.shape[0]).astype("bool"))
+                self.selected_cells.append(np.array(list(sams[i].adata.obs_names)))
+                self.active_labels.append(np.zeros(sams[i].adata.shape[0]))
+                self.dd_opts.append(["Toggle cluster"])
+                self.gene_expressions.append(np.zeros(sams[i].adata.shape[0]))
+                self.marker_genes.append(
+                    np.array(list(sams[i].adata.var_names))[
+                        np.argsort(-sams[i].adata.var["weights"].values)
+                    ]
+                )
+                self.marker_genes_tt.append("Genes ranked by SAM weights.")
+                self.ds.append(0)                
+                title = 'Full dataset {}'.format(i)
+                self.create_plot(i, title)
+                self.update_dropdowns(i)            
         else:
             self.log('Initializing blank GUI.')
             tab = widgets.Tab(layout={"height": "95%", "width": "50%"})
@@ -130,6 +153,13 @@ class SAMGUI(object):
         rm = list(invalidArgs(self.sams[0].preprocess_data,self.preprocess_args))
         for k in rm:
             del self.preprocess_args[k]            
+        self.preprocess_args['filter_genes']=False
+        self.preprocess_args['min_expression']=0
+        self.preprocess_args['thresh']=0
+        self.preprocess_args['thresh_low']=0
+        self.preprocess_args['thresh_high']=1
+        self.preprocess_args['sum_norm']=None
+        self.preprocess_args['norm']=None
         self.preprocess_args_init = self.preprocess_args.copy()
 
         try:
@@ -320,7 +350,7 @@ class SAMGUI(object):
         pdata.on_click(self.preprocess_sam)
         """
         fgenes = widgets.Checkbox(
-            value=bool(self.preprocess_args.get("filter_genes", True)),
+            value=bool(self.preprocess_args.get("filter_genes", False)),
             description="Filter genes",
         )
         fgenes.observe(self.pp_filtergenes, names="value")
@@ -334,7 +364,7 @@ class SAMGUI(object):
 
         l1 = widgets.Label("Expr threshold:")
         expr_thr = widgets.FloatSlider(
-            value=float(self.preprocess_args.get("thresh", 0.01)),
+            value=float(self.preprocess_args.get("thresh", 0.0)),
             min=0,
             max=0.1,
             step=0.005,
@@ -349,7 +379,7 @@ class SAMGUI(object):
 
         l2 = widgets.Label("Min expr:")
         min_expr = widgets.FloatSlider(
-            value=float(self.preprocess_args.get("min_expression", 1)),
+            value=float(self.preprocess_args.get("min_expression", 0)),
             min=0,
             max=6.0,
             step=0.02,
@@ -369,7 +399,7 @@ class SAMGUI(object):
             init = "None"
         sumnorm = widgets.Dropdown(
             options=["cell_median", "gene_median", "None"],
-            value=init,
+            value="None",
             description="Library normalization:",
             disabled=False,
             style={"description_width": "initial"},
@@ -383,7 +413,7 @@ class SAMGUI(object):
             init = "None"
         norm = widgets.Dropdown(
             options=["log", "ftt", "None"],
-            value=init,
+            value="None",
             description="Data normalization:",
             disabled=False,
             style={"description_width": "initial"},
@@ -1457,18 +1487,21 @@ class SAMGUI(object):
         if text != "" and text_name != "" and selected.sum() != selected.size:
             self.log(('Annotating cells with the {} label in the {} key.'.format(text,text_name),selected_cells))
             for it, s in enumerate(self.sams):
-                x1 = np.array(list(s.adata.obs_names))
-
-                if text_name in list(s.adata.obs.keys()):
-                    a = s.get_labels(text_name).copy().astype("<U100")
-                    a[np.in1d(x1, selected_cells)] = text
-                    s.adata.obs[text_name] = pd.Categorical(a)
-
-                else:
-                    a = np.zeros(s.adata.shape[0], dtype="<U100")
-                    a[:] = ""
-                    a[np.in1d(x1, selected_cells)] = text
-                    s.adata.obs[text_name] = pd.Categorical(a)
+                try:
+                    x1 = np.array(list(s.adata.obs_names))
+    
+                    if text_name in list(s.adata.obs.keys()):
+                        a = s.get_labels(text_name).copy().astype("<U100")
+                        a[np.in1d(x1, selected_cells)] = text
+                        s.adata.obs[text_name] = pd.Categorical(a)
+    
+                    else:
+                        a = np.zeros(s.adata.shape[0], dtype="<U100")
+                        a[:] = ""
+                        a[np.in1d(x1, selected_cells)] = text
+                        s.adata.obs[text_name] = pd.Categorical(a)
+                except:
+                    pass
                 
                 self.update_dropdowns(it)
 
