@@ -10,7 +10,7 @@ from sklearn.utils import check_array, check_random_state
 from scipy import sparse
 import sklearn.utils.sparsefuncs as sf
 from umap.umap_ import nearest_neighbors
-__version__ = "0.7.7"
+__version__ = "0.7.8"
 
 
 def find_corr_genes(sam, input_gene):
@@ -355,7 +355,6 @@ def nearest_neighbors_hnsw(x,ef=200,M=48,n_neighbors = 100):
     p.add_items(x, labels)
     p.set_ef(ef)
     idx, dist = p.knn_query(x, k = n_neighbors)
-    dist = (2-dist)/2
     return idx,dist
 
 
@@ -366,13 +365,7 @@ def calc_nnm(g_weighted, k, distance=None):
         else:
             nnm, dists = nearest_neighbors_wrapper(g_weighted, n_neighbors=k, metric=distance)
         EDM = gen_sparse_knn(nnm, dists)
-        EDM = EDM.tocsr()
-    else: #try removing this and only use stochastic 
-        if sp.sparse.issparse(g_weighted):
-            g_weighted = g_weighted.A
-        dist = compute_distances(g_weighted, distance)
-        nnm = dist_to_nn(dist, k)
-        EDM = sp.sparse.csr_matrix(nnm)
+        EDM = EDM.tocsr()        
     return EDM
 
 
